@@ -5,19 +5,15 @@ natsort public API.
 
 The majority of the "work" is defined in utils.py.
 """
-from __future__ import absolute_import, division, print_function, unicode_literals
 
-import sys
 from functools import partial
 from operator import itemgetter
 
 import natsort.compat.locale
 from natsort import utils
-from natsort.compat.py23 import py23_cmp, py23_str, u_format
 from natsort.ns_enum import NS_DUMB, ns
 
 
-@u_format
 def decoder(encoding):
     """
     Return a function that can be used to decode bytes to unicode.
@@ -59,7 +55,6 @@ def decoder(encoding):
     return partial(utils.do_decoding, encoding=encoding)
 
 
-@u_format
 def as_ascii(s):
     """
     Function to decode an input with the ASCII codec, or return as-is.
@@ -83,7 +78,6 @@ def as_ascii(s):
     return utils.do_decoding(s, "ascii")
 
 
-@u_format
 def as_utf8(s):
     """
     Function to decode an input with the UTF-8 codec, or return as-is.
@@ -107,7 +101,6 @@ def as_utf8(s):
     return utils.do_decoding(s, "utf-8")
 
 
-@u_format
 def natsort_keygen(key=None, alg=ns.DEFAULT):
     """
     Generate a key to sort strings and numbers naturally.
@@ -151,14 +144,14 @@ def natsort_keygen(key=None, alg=ns.DEFAULT):
         >>> a = ['num5.10', 'num-3', 'num5.3', 'num2']
         >>> a.sort(key=natsort_keygen(alg=ns.REAL))
         >>> a
-        [{u}'num-3', {u}'num2', {u}'num5.10', {u}'num5.3']
+        ['num-3', 'num2', 'num5.10', 'num5.3']
 
     """
     try:
         ns.DEFAULT | alg
     except TypeError:
         msg = "natsort_keygen: 'alg' argument must be from the enum 'ns'"
-        raise ValueError(msg + ", got {}".format(py23_str(alg)))
+        raise ValueError(msg + ", got {}".format(str(alg)))
 
     # Add the NS_DUMB option if the locale library is broken.
     if alg & ns.LOCALEALPHA and natsort.compat.locale.dumb_sort():
@@ -218,7 +211,6 @@ natsort_keygen
 """
 
 
-@u_format
 def natsorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
     """
     Sorts an iterable naturally.
@@ -260,14 +252,13 @@ def natsorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
 
         >>> a = ['num3', 'num5', 'num2']
         >>> natsorted(a)
-        [{u}'num2', {u}'num3', {u}'num5']
+        ['num2', 'num3', 'num5']
 
     """
     key = natsort_keygen(key, alg)
     return sorted(seq, reverse=reverse, key=key)
 
 
-@u_format
 def humansorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
     """
     Convenience function to properly sort non-numeric characters.
@@ -312,15 +303,14 @@ def humansorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
 
         >>> a = ['Apple', 'Banana', 'apple', 'banana']
         >>> natsorted(a)
-        [{u}'Apple', {u}'Banana', {u}'apple', {u}'banana']
+        ['Apple', 'Banana', 'apple', 'banana']
         >>> humansorted(a)
-        [{u}'apple', {u}'Apple', {u}'banana', {u}'Banana']
+        ['apple', 'Apple', 'banana', 'Banana']
 
     """
     return natsorted(seq, key, reverse, alg | ns.LOCALE)
 
 
-@u_format
 def realsorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
     """
     Convenience function to properly sort signed floats.
@@ -366,15 +356,14 @@ def realsorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
 
         >>> a = ['num5.10', 'num-3', 'num5.3', 'num2']
         >>> natsorted(a)
-        [{u}'num2', {u}'num5.3', {u}'num5.10', {u}'num-3']
+        ['num2', 'num5.3', 'num5.10', 'num-3']
         >>> realsorted(a)
-        [{u}'num-3', {u}'num2', {u}'num5.10', {u}'num5.3']
+        ['num-3', 'num2', 'num5.10', 'num5.3']
 
     """
     return natsorted(seq, key, reverse, alg | ns.REAL)
 
 
-@u_format
 def index_natsorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
     """
     Determine the list of the indexes used to sort the input sequence.
@@ -426,9 +415,9 @@ def index_natsorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
         [2, 0, 1]
         >>> # Sort both lists by the sort order of a
         >>> order_by_index(a, index)
-        [{u}'num2', {u}'num3', {u}'num5']
+        ['num2', 'num3', 'num5']
         >>> order_by_index(b, index)
-        [{u}'baz', {u}'foo', {u}'bar']
+        ['baz', 'foo', 'bar']
 
     """
     if key is None:
@@ -439,12 +428,11 @@ def index_natsorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
             return key(itemgetter(1)(x))
 
     # Pair the index and sequence together, then sort by element
-    index_seq_pair = [[x, y] for x, y in enumerate(seq)]
+    index_seq_pair = [(x, y) for x, y in enumerate(seq)]
     index_seq_pair.sort(reverse=reverse, key=natsort_keygen(newkey, alg))
     return [x for x, _ in index_seq_pair]
 
 
-@u_format
 def index_humansorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
     """
     This is a wrapper around ``index_natsorted(seq, alg=ns.LOCALE)``.
@@ -494,7 +482,6 @@ def index_humansorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
     return index_natsorted(seq, key, reverse, alg | ns.LOCALE)
 
 
-@u_format
 def index_realsorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
     """
     This is a wrapper around ``index_natsorted(seq, alg=ns.REAL)``.
@@ -541,7 +528,6 @@ def index_realsorted(seq, key=None, reverse=False, alg=ns.DEFAULT):
 
 
 # noinspection PyShadowingBuiltins,PyUnresolvedReferences
-@u_format
 def order_by_index(seq, index, iter=False):
     """
     Order a given sequence by an index sequence.
@@ -593,67 +579,28 @@ def order_by_index(seq, index, iter=False):
         [2, 0, 1]
         >>> # Sort both lists by the sort order of a
         >>> order_by_index(a, index)
-        [{u}'num2', {u}'num3', {u}'num5']
+        ['num2', 'num3', 'num5']
         >>> order_by_index(b, index)
-        [{u}'baz', {u}'foo', {u}'bar']
+        ['baz', 'foo', 'bar']
 
     """
     return (seq[i] for i in index) if iter else [seq[i] for i in index]
 
 
-if float(sys.version[:3]) < 3:
-    # pylint: disable=unused-variable
-    # noinspection PyUnresolvedReferences,PyPep8Naming
-    class natcmp(object):  # noqa: N801
-        """
-        Compare two objects using a key and an algorithm.
+def numeric_regex_chooser(alg):
+    """
+    Select an appropriate regex for the type of number of interest.
 
-        Parameters
-        ----------
-        x : object
-            First object to compare.
+    Parameters
+    ----------
+    alg : ns enum
+        Used to indicate the regular expression to select.
 
-        y : object
-            Second object to compare.
+    Returns
+    -------
+    regex : str
+        Regular expression string that matches the desired number type.
 
-        alg : ns enum, optional
-            This option is used to control which algorithm `natsort`
-            uses when sorting. For details into these options, please see
-            the :class:`ns` class documentation. The default is `ns.INT`.
-
-        Returns
-        -------
-        out: int
-            0 if x and y are equal, 1 if x > y, -1 if y > x.
-
-        See Also
-        --------
-        natsort_keygen : Generates a key that makes natural sorting possible.
-
-        Examples
-        --------
-        Use `natcmp` just like the builtin `cmp`::
-
-            >>> one = 1
-            >>> two = 2
-            >>> natcmp(one, two)
-            -1
-        """
-
-        cached_keys = {}
-
-        def __new__(cls, x, y, alg=ns.DEFAULT):
-            try:
-                ns.DEFAULT | alg
-            except TypeError:
-                msg = "natsort_keygen: 'alg' argument must be from the enum 'ns'"
-                raise ValueError(msg + ", got {}".format(py23_str(alg)))
-
-            # Add the _DUMB option if the locale library is broken.
-            if alg & ns.LOCALEALPHA and natsort.compat.locale.dumb_sort():
-                alg |= NS_DUMB
-
-            if alg not in cls.cached_keys:
-                cls.cached_keys[alg] = natsort_keygen(alg=alg)
-
-            return py23_cmp(cls.cached_keys[alg](x), cls.cached_keys[alg](y))
+    """
+    # Remove the leading and trailing parens
+    return utils.regex_chooser(alg).pattern[1:-1]
